@@ -6,34 +6,34 @@ from dataclassy.functions import is_dataclass_instance
 
 
 def as_dict(
-    obj: DataClass,
-    flatten: bool = False
+        obj: DataClass,
+        flatten: bool = False
 ) -> Dict[str, Any]:
     if flatten:
-        return funcy.merge(*(
+        return funcy.join(
             (
                 as_dict(field, flatten=flatten)
                 if is_dataclass_instance(field)
                 else {field_name: field}
             )
             for field_name, field in values(obj).items()
-        ))
+        )
     else:
         return asdict(obj)
 
 
 def as_tuple(
-    obj: DataClass,
-    flatten: bool = False
+        obj: DataClass,
+        flatten: bool = False
 ) -> tuple:
     if flatten:
-        return funcy.merge(*(
+        return funcy.join(
             (
                 as_tuple(field, flatten=flatten)
                 if is_dataclass_instance(field)
                 else (field,)
             )
-            for field in obj
-        ))
+            for field in values(obj).values()
+        )
     else:
         return astuple(obj)
